@@ -23,6 +23,7 @@
 #include <config.h>
 #include <gthumb.h>
 #include "dlg-edit-metadata.h"
+#include "gth-delete-metadata-task.h"
 #include "gth-tag-chooser-dialog.h"
 #include "gth-tag-task.h"
 
@@ -108,3 +109,46 @@ gth_browser_activate_action_edit_tag_files (GtkAction  *action,
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (browser));
 	gtk_window_present (GTK_WINDOW (dialog));
 }
+
+
+void
+gth_browser_activate_action_tool_delete_metadata (GtkAction  *action,
+						  GthBrowser *browser)
+{
+	GtkWidget *dialog;
+	int        result;
+	GList     *items;
+	GList     *file_data_list;
+	GList     *file_list;
+	GthTask   *task;
+
+	dialog =  gtk_message_dialog_new (GTK_WINDOW (browser),
+					  GTK_DIALOG_MODAL,
+					  GTK_MESSAGE_QUESTION,
+					  GTK_BUTTONS_NONE,
+					  _("Are you sure you want to permanently delete the metadata of the selected files?"));
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+			        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			        GTK_STOCK_DELETE, GTK_RESPONSE_YES,
+			        NULL);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  "%s",
+						  _("If you delete the metadata, it will be permanently lost."));
+
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+
+	if (result != GTK_RESPONSE_YES)
+		return;
+
+	items = gth_file_selection_get_selected (GTH_FILE_SELECTION (gth_browser_get_file_list_view (browser)));
+	file_data_list = gth_file_list_get_files (GTH_FILE_LIST (gth_browser_get_file_list (browser)), items);
+	file_list = gth_file_data_list_to_file_list (file_data_list);
+	task = gth_delete_metadata_task_new (browser, file_list);
+	gth_browser_exec_task (browser, task, FALSE);
+
+	g_object_unref (task);
+	_g_object_list_unref (file_list);
+	_g_object_list_unref (file_data_list);
+	_gtk_tree_path_list_free (items);
+}
