@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -47,15 +46,20 @@ static const char *ui_info =
 "      </menu>"
 "    </menu>"
 "  </menubar>"
+"  <popup name='ExportPopup'>"
+"    <placeholder name='Web_Services'>"
+"      <menuitem action='File_Export_PicasaWeb'/>"
+"    </placeholder>"
+"  </popup>"
 "</ui>";
 
 
 static GtkActionEntry action_entries[] = {
-	{ "File_Import_PicasaWeb", "picasaweb",
+	{ "File_Import_PicasaWeb", "site-picasaweb",
 	  N_("_Picasa Web Album..."), NULL,
 	  N_("Download photos from Picasa Web Album"),
 	  G_CALLBACK (gth_browser_activate_action_import_picasaweb) },
-	{ "File_Export_PicasaWeb", "picasaweb",
+	{ "File_Export_PicasaWeb", "site-picasaweb",
 	  N_("_Picasa Web Album..."), NULL,
 	  N_("Upload photos to Picasa Web Album"),
 	  G_CALLBACK (gth_browser_activate_action_export_picasaweb) },
@@ -99,5 +103,9 @@ pw__gth_browser_construct_cb (GthBrowser *browser)
 		g_clear_error (&error);
 	}
 
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (gtk_ui_manager_get_widget (gth_browser_get_ui_manager (browser), "/MenuBar/File/Import/Web_Services/File_Import_PicasaWeb")), TRUE);
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (gtk_ui_manager_get_widget (gth_browser_get_ui_manager (browser), "/MenuBar/File/Export/Web_Services/File_Export_PicasaWeb")), TRUE);
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (gtk_ui_manager_get_widget (gth_browser_get_ui_manager (browser), "/ExportPopup/Web_Services/File_Export_PicasaWeb")), TRUE);
+
 	g_object_set_data_full (G_OBJECT (browser), BROWSER_DATA_KEY, data, (GDestroyNotify) browser_data_free);
 }
