@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef PREFERENCES_H
@@ -29,6 +28,7 @@
 #define  PREF_SLIDESHOW_WRAP_AROUND      "/apps/gthumb/ext/slideshow/wrap_around"
 #define  PREF_SLIDESHOW_AUTOMATIC        "/apps/gthumb/ext/slideshow/automatic"
 #define  PREF_SLIDESHOW_TRANSITION       "/apps/gthumb/ext/slideshow/transition"
+#define  PREF_SLIDESHOW_RANDOM_ORDER     "/apps/gthumb/ext/slideshow/random-order"
 
 #define  DEFAULT_TRANSITION "random"
 
